@@ -28,6 +28,16 @@ class GmeClient(AbstractClient):
 
     def CreateAgeDetectTask(self, request):
         """用于创建年龄语音识别任务的接口，请求频率10次/秒。该接口目前通过白名单开放试用，如有需求，请提交工单申请。
+        </br>
+        <h4><b>接口功能说明：</b></h4>
+        <li>支持对语音文件进行检测，判断是否为未成年人。</li>
+        <li>支持批量提交检测子任务。检测子任务列表最多支持100个。</li>
+        </br>
+        <h4><b>音频文件限制说明：</b></h4>
+        <li>音频文件大小限制：10 M</li>
+        <li>音频文件时长限制：3分钟</li>
+        <li>音频文件格式支持的类型：.wav、.m4a、.amr、.mp3、.aac、.wma、.ogg</li>
+        </br>
 
         :param request: Request instance for CreateAgeDetectTask.
         :type request: :class:`tencentcloud.gme.v20180711.models.CreateAgeDetectTaskRequest`
